@@ -1,6 +1,7 @@
 import ama_xiv_combat_sim.simulator.game_data.patch_655.job_class_fns as patch655
 import ama_xiv_combat_sim.simulator.game_data.patch_70.job_class_fns as patch70
 import ama_xiv_combat_sim.simulator.game_data.patch_701.job_class_fns as patch701
+import ama_xiv_combat_sim.simulator.game_data.patch_705.job_class_fns as patch705
 #we shouldn't put testing here...
 import ama_xiv_combat_sim.simulator.game_data.testing.job_class_fns as testing
 
@@ -12,6 +13,8 @@ def get_job_class_fns(version):
             return patch70.JobClassFns
         case "7.01":
             return patch701.JobClassFns
+        case "7.05":
+            return patch705.JobClassFns
         case "test":
             return testing.JobClassFns
         case _:
