@@ -35,7 +35,7 @@ def add_gnb_skills(skill_library):
         Skill(
             name="Keen Edge",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=280),
+            damage_spec=DamageSpec(potency=300),
             combo_spec=(ComboSpec(combo_group=0),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=893
@@ -75,6 +75,7 @@ def add_gnb_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=626
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -92,8 +93,8 @@ def add_gnb_skills(skill_library):
             name="Solid Barrel",
             is_GCD=True,
             damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=440),
-                "No Combo": DamageSpec(potency=220),
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=460),
+                "No Combo": DamageSpec(potency=240),
             },
             combo_spec=(ComboSpec(combo_group=0, combo_actions=("Brutal Shell",)),),
             timing_spec=TimingSpec(
@@ -105,7 +106,7 @@ def add_gnb_skills(skill_library):
         Skill(
             name="Burst Strike",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=440),
+            damage_spec=DamageSpec(potency=460),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=714
             ),
@@ -123,6 +124,7 @@ def add_gnb_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=626
             ),
+            has_aoe=True
         )
     )
     sonic_break_dot = Skill(
@@ -154,7 +156,7 @@ def add_gnb_skills(skill_library):
         Skill(
             name="Gnashing Fang",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=460),
+            damage_spec=DamageSpec(potency=500),
             combo_spec=(ComboSpec(combo_group=1),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
@@ -165,7 +167,7 @@ def add_gnb_skills(skill_library):
         Skill(
             name="Savage Claw",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=540),
+            damage_spec=DamageSpec(potency=560),
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Gnashing Fang",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=625
@@ -205,6 +207,7 @@ def add_gnb_skills(skill_library):
                     snapshot_debuffs_with_parent=True,
                 ),
             ),
+            has_aoe=True
         )
     )
 
@@ -246,6 +249,7 @@ def add_gnb_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=537
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -272,10 +276,12 @@ def add_gnb_skills(skill_library):
         Skill(
             name="Double Down",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=1200),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=1200)},    
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=716
             ),
+            has_aoe=True,
+            aoe_dropoff= 0.15
         )
     )
     skill_library.add_skill(
@@ -284,38 +290,45 @@ def add_gnb_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=758
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
         Skill(
             name="Reign of Beasts",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=800),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=800)},
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=758
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
         Skill(
             name="Noble Blood",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=1000),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=1000)},
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=758
+                base_cast_time=0, animation_lock=650, application_delay=1650
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
         Skill(
             name="Lion Heart",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=1200),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=1200)},
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=758
+                base_cast_time=0, animation_lock=650, application_delay=1790
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )           
     # These skills do not damage, but grants resources/affects future skills.
