@@ -27,7 +27,7 @@ def add_mnk_skills(skill_library):
                 num_uses=1,
                 duration=math.inf,
                 add_to_skill_modifier_condition=True,
-                skill_allowlist=("Rising Raptor","True Strike"),
+                skill_allowlist=("Rising Raptor", "True Strike"),
             ),
         ),
         delay_after_parent_application=0,
@@ -39,7 +39,7 @@ def add_mnk_skills(skill_library):
                 num_uses=2,
                 duration=math.inf,
                 add_to_skill_modifier_condition=True,
-                skill_allowlist=("Pouncing Coeurl","Snap Punch"),
+                skill_allowlist=("Pouncing Coeurl", "Snap Punch"),
             ),
         ),
         delay_after_parent_application=0,
@@ -51,11 +51,11 @@ def add_mnk_skills(skill_library):
                 num_uses=1,
                 duration=math.inf,
                 add_to_skill_modifier_condition=True,
-                skill_allowlist=("Leaping Opo","Bootshine"),
+                skill_allowlist=("Leaping Opo", "Bootshine"),
             ),
         ),
         delay_after_parent_application=0,
-    )    
+    )
     opo_opo_form_skill = Skill(
         name="Opo-opo Form",
         is_GCD=False,
@@ -68,7 +68,7 @@ def add_mnk_skills(skill_library):
                 "Bootshine",
                 "Dragon Kick",
                 "Shadow of the Destroyer",
-                'Leaping Opo'
+                "Leaping Opo",
             ),
         ),
     )
@@ -118,19 +118,19 @@ def add_mnk_skills(skill_library):
                     "True Strike",
                     "Snap Punch",
                     "Dragon Kick",
-                    "Shadow of the Destroyer",                    
+                    "Shadow of the Destroyer",
                     "Twin Snakes",
                     "Demolish",
                     "Rockbreaker",
                     "Four-point Fury",
                     "Elixir Burst",
                     "Fire's Reply",
-                    "Leaping Opo"
+                    "Leaping Opo",
                 ),
             ),
         ),
         delay_after_parent_application=0,
-        primary_target_only=True
+        primary_target_only=True,
     )
 
     skill_library.add_skill(
@@ -173,7 +173,10 @@ def add_mnk_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=1110, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1110,
+                gcd_base_recast_time=2000,
             ),
         )
     )
@@ -181,10 +184,15 @@ def add_mnk_skills(skill_library):
         Skill(
             name="True Strike",
             is_GCD=True,
-            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=300),
-                         "Raptor's Fury": DamageSpec(potency=500)},
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=300),
+                "Raptor's Fury": DamageSpec(potency=500),
+            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=800, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=800,
+                gcd_base_recast_time=2000,
             ),
         )
     )
@@ -200,7 +208,10 @@ def add_mnk_skills(skill_library):
                 "Coeurl's Fury, No Positional": DamageSpec(potency=420),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=760, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=760,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(opo_opo_form_follow_up,),
         )
@@ -211,7 +222,10 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=420),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=840, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=840,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(raptor_fury_follow_up,),
         )
@@ -232,9 +246,16 @@ def add_mnk_skills(skill_library):
             name="Demolish",
             is_GCD=True,
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=0, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=0,
+                gcd_base_recast_time=2000,
+            ),
+            follow_up_skills=(
+                demolish_damage_follow_up,
+                opo_opo_form_follow_up,
+                coeurl_fury_follow_up,
             ),
-            follow_up_skills=(demolish_damage_follow_up, opo_opo_form_follow_up, coeurl_fury_follow_up),
         )
     )
     skill_library.add_skill(
@@ -243,10 +264,13 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=150),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=940, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=940,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(opo_opo_form_follow_up,),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -273,7 +297,7 @@ def add_mnk_skills(skill_library):
                 animation_lock=650,
                 application_delay=1290,
                 gcd_base_recast_time=2000,
-            ),            
+            ),
             follow_up_skills={
                 SimConsts.DEFAULT_CONDITION: tuple(),
                 "Opo-opo Form": (opo_opo_fury_follow_up,),
@@ -288,7 +312,7 @@ def add_mnk_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=400),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=1480
+                base_cast_time=0, animation_lock=650, application_delay=1420
             ),
         )
     )
@@ -298,11 +322,14 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=800),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=1070, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1070,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(formless_fist_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.7
+            aoe_dropoff=0.7,
         )
     )
     skill_library.add_skill(
@@ -311,7 +338,10 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=600),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=890, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=890,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(formless_fist_follow_up,),
         )
@@ -357,7 +387,7 @@ def add_mnk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=760
             ),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -365,20 +395,25 @@ def add_mnk_skills(skill_library):
             name="Six-sided Star",
             is_GCD=True,
             # can just construct dictionary in a loop, but i am lazy
-            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=780+5*80),
-                         '10 Chakra': DamageSpec(potency=780+10*80),
-                         '9 Chakra': DamageSpec(potency=780+9*80),
-                         '8 Chakra': DamageSpec(potency=780+8*80),
-                         '7 Chakra': DamageSpec(potency=780+7*80),
-                         '6 Chakra': DamageSpec(potency=780+6*80),
-                         '5 Chakra': DamageSpec(potency=780+5*80),
-                         '4 Chakra': DamageSpec(potency=780+4*80),
-                         '3 Chakra': DamageSpec(potency=780+3*80),
-                         '2 Chakra': DamageSpec(potency=780+2*80),
-                         '1 Chakra': DamageSpec(potency=780+1*80),
-                         '0 Chakra': DamageSpec(potency=780)},
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=780 + 5 * 80),
+                "10 Chakra": DamageSpec(potency=780 + 10 * 80),
+                "9 Chakra": DamageSpec(potency=780 + 9 * 80),
+                "8 Chakra": DamageSpec(potency=780 + 8 * 80),
+                "7 Chakra": DamageSpec(potency=780 + 7 * 80),
+                "6 Chakra": DamageSpec(potency=780 + 6 * 80),
+                "5 Chakra": DamageSpec(potency=780 + 5 * 80),
+                "4 Chakra": DamageSpec(potency=780 + 4 * 80),
+                "3 Chakra": DamageSpec(potency=780 + 3 * 80),
+                "2 Chakra": DamageSpec(potency=780 + 2 * 80),
+                "1 Chakra": DamageSpec(potency=780 + 1 * 80),
+                "0 Chakra": DamageSpec(potency=780),
+            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620, gcd_base_recast_time=4000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,
+                gcd_base_recast_time=4000,
             ),
         )
     )
@@ -399,9 +434,12 @@ def add_mnk_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=400, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=400,
+                gcd_base_recast_time=2000,
             ),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -410,11 +448,14 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=900),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=760, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=760,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(formless_fist_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.7
+            aoe_dropoff=0.7,
         )
     )
     skill_library.add_skill(
@@ -423,11 +464,14 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=1400),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=400, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=400,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(formless_fist_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.5
+            aoe_dropoff=0.5,
         )
     )
     skill_library.add_skill(
@@ -458,7 +502,10 @@ def add_mnk_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=400, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,
+                gcd_base_recast_time=2000,
             ),
         )
     )
@@ -466,10 +513,15 @@ def add_mnk_skills(skill_library):
         Skill(
             name="Rising Raptor",
             is_GCD=True,
-            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=340),
-                         "Raptor's Fury": DamageSpec(potency=540)},
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=340),
+                "Raptor's Fury": DamageSpec(potency=540),
+            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=760, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=890,
+                gcd_base_recast_time=2000,
             ),
         )
     )
@@ -477,14 +529,23 @@ def add_mnk_skills(skill_library):
         Skill(
             name="Pouncing Coeurl",
             is_GCD=True,
-            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=370, use_min_potency=310),
-                         "Coeurl's Fury": DamageSpec(potency=520, use_min_potency=460),
-                         "No Positional":  DamageSpec(potency=310, use_min_potency=310),
-                         "Coeurl's Fury, No Positional":  DamageSpec(potency=460, use_min_potency=460)},
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(
+                    potency=370, use_min_potency=310
+                ),
+                "Coeurl's Fury": DamageSpec(potency=520, use_min_potency=460),
+                "No Positional": DamageSpec(potency=310, use_min_potency=310),
+                "Coeurl's Fury, No Positional": DamageSpec(
+                    potency=460, use_min_potency=460
+                ),
+            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=760, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1020,
+                gcd_base_recast_time=2000,
             ),
-            follow_up_skills=(opo_opo_form_follow_up,)
+            follow_up_skills=(opo_opo_form_follow_up,),
         )
     )
     skill_library.add_skill(
@@ -493,11 +554,14 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=900),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=400, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1420,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(formless_fist_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.7
+            aoe_dropoff=0.7,
         )
     )
     skill_library.add_skill(
@@ -506,10 +570,13 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=800),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=400, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1200,
+                gcd_base_recast_time=2000,
             ),
             has_aoe=True,
-            aoe_dropoff=0.5
+            aoe_dropoff=0.5,
         )
     )
     skill_library.add_skill(
@@ -518,11 +585,14 @@ def add_mnk_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=400, gcd_base_recast_time=2000
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=1420,
+                gcd_base_recast_time=2000,
             ),
             follow_up_skills=(formless_fist_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.5
+            aoe_dropoff=0.5,
         )
     )
 
@@ -554,13 +624,19 @@ def add_mnk_skills(skill_library):
         Skill(name="Steeled Meditation", is_GCD=False, timing_spec=instant_timing_spec)
     )
     skill_library.add_skill(
-        Skill(name="Inspirited Meditation", is_GCD=False, timing_spec=instant_timing_spec)
+        Skill(
+            name="Inspirited Meditation", is_GCD=False, timing_spec=instant_timing_spec
+        )
     )
     skill_library.add_skill(
-        Skill(name="Forbidden Meditation", is_GCD=False, timing_spec=instant_timing_spec)
+        Skill(
+            name="Forbidden Meditation", is_GCD=False, timing_spec=instant_timing_spec
+        )
     )
     skill_library.add_skill(
-        Skill(name="Enlightened Meditation", is_GCD=False, timing_spec=instant_timing_spec)
+        Skill(
+            name="Enlightened Meditation", is_GCD=False, timing_spec=instant_timing_spec
+        )
     )
 
     skill_library.add_skill(
