@@ -16,8 +16,8 @@ class TestDamageSimulator(TestClass):
   def test_trait_damage_mult_override(self):
     stats = Stats(wd=126, weapon_delay=3.44, main_stat=2945, det_stat=1620, crit_stat=2377, dh_stat=1048, speed_stat=708, job_class = 'test_job2', version="test")
     dmg_instances = [
-                 (0, self.__skill_library.get_skill('test_gcd', 'test_job2'), SkillModifier(), (StatusEffects(), StatusEffects()),1),
-                 (1000, self.__skill_library.get_skill('test_gcd_trait_override', 'test_job2'), SkillModifier(), (StatusEffects(), StatusEffects()),2)]
+                 (0, self.__skill_library.get_skill('test_gcd', 'test_job2'), SkillModifier(), (StatusEffects(), StatusEffects()),1, 't1'),
+                 (1000, self.__skill_library.get_skill('test_gcd_trait_override', 'test_job2'), SkillModifier(), (StatusEffects(), StatusEffects()),2, 't1')]
 
     sim = DamageSimulator(stats, dmg_instances, 2)
     expected_trait_damage_mult = [1.4, 1.0]
@@ -27,9 +27,9 @@ class TestDamageSimulator(TestClass):
   @TestClass.is_a_test
   def test_guaranteed_crit_dh_dot(self):
     dmg_instances = [
-                 (0, self.__skill_library.get_skill('test_guaranteed_crit_dot', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),1),
-                 (1000, self.__skill_library.get_skill('test_guaranteed_dh_dot', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),2),
-                 (2000, self.__skill_library.get_skill('test_guaranteed_crit_dh_dot', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),3)]
+                 (0, self.__skill_library.get_skill('test_guaranteed_crit_dot', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),1, 't1'),
+                 (1000, self.__skill_library.get_skill('test_guaranteed_dh_dot', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),2, 't1'),
+                 (2000, self.__skill_library.get_skill('test_guaranteed_crit_dh_dot', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),3, 't1')]
 
     sim = DamageSimulator(self.__stats, dmg_instances, 2)
     expected_crit = [1, self.__stats.processed_stats.crit_rate, 1]
@@ -42,8 +42,8 @@ class TestDamageSimulator(TestClass):
   @TestClass.is_a_test
   def test_guaranteed_no_crit_dh(self):
     dmg_instances = [
-                 (0, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),1),
-                 (2000, self.__skill_library.get_skill('test_guaranteed_no_crit_dh', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),2)]
+                 (0, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),1, 't1'),
+                 (2000, self.__skill_library.get_skill('test_guaranteed_no_crit_dh', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),2, 't1')]
 
     sim = DamageSimulator(self.__stats, dmg_instances, 2)
     expected_crit = [self.__stats.processed_stats.crit_rate, 0]
@@ -56,8 +56,8 @@ class TestDamageSimulator(TestClass):
   @TestClass.is_a_test
   def test_guaranteed_crit_dh_from_status_effects(self):
     dmg_instances = [
-                 (0, self.__skill_library.get_skill('test_instant_gcd', 'test_job'), SkillModifier(), (StatusEffects(guaranteed_crit=ForcedCritOrDH.FORCE_YES), StatusEffects()),1),
-                 (1000, self.__skill_library.get_skill('test_instant_gcd', 'test_job'), SkillModifier(), (StatusEffects(guaranteed_dh=ForcedCritOrDH.FORCE_YES), StatusEffects()),2)]
+                 (0, self.__skill_library.get_skill('test_instant_gcd', 'test_job'), SkillModifier(), (StatusEffects(guaranteed_crit=ForcedCritOrDH.FORCE_YES), StatusEffects()),1, 't1'),
+                 (1000, self.__skill_library.get_skill('test_instant_gcd', 'test_job'), SkillModifier(), (StatusEffects(guaranteed_dh=ForcedCritOrDH.FORCE_YES), StatusEffects()),2, 't1')]
 
     sim = DamageSimulator(self.__stats, dmg_instances, 2)
     expected_crit = [1, self.__stats.processed_stats.crit_rate]
@@ -70,9 +70,9 @@ class TestDamageSimulator(TestClass):
   @TestClass.is_a_test
   def test_guaranteed_crit_dh(self):
     dmg_instances = [
-                 (0, self.__skill_library.get_skill('test_guaranteed_crit', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),1),
-                 (1000, self.__skill_library.get_skill('test_guaranteed_dh', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),2),
-                 (2000, self.__skill_library.get_skill('test_guaranteed_crit_dh', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),3)]
+                 (0, self.__skill_library.get_skill('test_guaranteed_crit', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),1, 't1'),
+                 (1000, self.__skill_library.get_skill('test_guaranteed_dh', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),2, 't1'),
+                 (2000, self.__skill_library.get_skill('test_guaranteed_crit_dh', 'test_job'), SkillModifier(), (StatusEffects(), StatusEffects()),3, 't1')]
 
     sim = DamageSimulator(self.__stats, dmg_instances, 2)
     expected_crit = [1, self.__stats.processed_stats.crit_rate, 1]
@@ -85,9 +85,9 @@ class TestDamageSimulator(TestClass):
   @TestClass.is_a_test
   def test_guaranteed_crit_dh_with_skill_modifier(self):
     dmg_instances = [
-                 (0, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES), (StatusEffects(), StatusEffects()),1),
-                 (1000, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES), (StatusEffects(), StatusEffects()),2),
-                 (2000, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES, guaranteed_dh=ForcedCritOrDH.FORCE_YES), (StatusEffects(), StatusEffects()),3)]
+                 (0, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES), (StatusEffects(), StatusEffects()),1, 't1'),
+                 (1000, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES), (StatusEffects(), StatusEffects()),2, 't1'),
+                 (2000, self.__skill_library.get_skill('test_gcd', 'test_job'), SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES, guaranteed_dh=ForcedCritOrDH.FORCE_YES), (StatusEffects(), StatusEffects()),3, 't1')]
 
     sim = DamageSimulator(self.__stats, dmg_instances, 2)
     expected_crit = [1, self.__stats.processed_stats.crit_rate, 1]
